import predictor, sys, datetime
import pandas as pd
from dateutil.relativedelta import relativedelta

def run(measure):
   output_table = []
   for sport in df["sport"].drop_duplicates().sort_values():
      sport_table = df[df["sport"] == sport].copy()
      for season in sport_table["season"].drop_duplicates().sort_values():
         data_tables = []
         for league in sport_table["league"].drop_duplicates().sort_values():
            league_table = sport_table[sport_table["league"] == league].copy()
            start = league_table[league_table["season"] == season]["date"].min()
            if not pd.isnull(start):
               start = pd.to_datetime(league_table[league_table["season"] == season]["date"].min(), format = "%Y%m%d") - relativedelta(years = 1)
               train_table = league_table[(pd.to_datetime(league_table["date"], format = "%Y%m%d") >= start) & (league_table["season"] < season)].copy()
               if train_table.shape[0] > 0:
                  test_table = league_table[league_table["season"] == season].copy()
                  data_tables.append(train_table)
                  data_tables.append(test_table)
         if len(data_tables) > 0:
            sys.stderr.write(f"{sport}\t{season}\t{measure}\n")
            auc, home_adv = predictor.predict(pd.concat(data_tables), predictor = measure)
            output_table.append((sport, season, auc, home_adv))
   return pd.DataFrame(data = output_table, columns = ("sport", "season", f"auc_{measure}", f"home_adv_{measure}"))

df = pd.read_csv("../data/sport_db.csv", sep = "\t")
output_df = pd.DataFrame(columns = ("sport", "season"))

for measure in ("pagerank", "naive", "elo"):
   output_table = run(measure)
   output_df = output_df.merge(output_table, on = ["sport", "season"], how = "outer")
   output_df.to_csv("figs_2_3_part1.csv", sep = "\t", index = False)

