import pandas as pd
import statsmodels.api as sm

df = pd.read_csv("figs_2_3_part1.csv", sep = "\t")
df = sm.add_constant(df)

print("AUC")
print("========================= PageRank =========================")
for sport in df["sport"].drop_duplicates().sort_values():
   auc_regr = sm.OLS(df.loc[df["sport"] == sport, "auc_pagerank"], df.loc[df["sport"] == sport, ["season", "const"]]).fit()
   arrow = "\\mathit{-}" if auc_regr.pvalues['season'] > 0.05 else "\\uparrow" if auc_regr.params['season'] > 0 else "\\downarrow"
   stars = "***" if auc_regr.pvalues['season'] < 0.001 else "**" if auc_regr.pvalues['season'] < 0.01 else "*" if auc_regr.pvalues['season'] < 0.05 else " "
   print(f"{sport.capitalize()} & ${arrow}$ & ${stars}$ & ${auc_regr.rsquared_adj:.2f}$\\\\")

print("========================= ELO =========================")
for sport in df["sport"].drop_duplicates().sort_values():
   auc_regr = sm.OLS(df.loc[df["sport"] == sport, "auc_elo"], df.loc[df["sport"] == sport, ["season", "const"]]).fit()
   arrow = "\\mathit{-}" if auc_regr.pvalues['season'] > 0.05 else "\\uparrow" if auc_regr.params['season'] > 0 else "\\downarrow"
   stars = "***" if auc_regr.pvalues['season'] < 0.001 else "**" if auc_regr.pvalues['season'] < 0.01 else "*" if auc_regr.pvalues['season'] < 0.05 else " "
   print(f"{sport.capitalize()} & ${arrow}$ & ${stars}$ & ${auc_regr.rsquared_adj:.2f}$\\\\")

print("========================= Naive =========================")
for sport in df["sport"].drop_duplicates().sort_values():
   auc_regr = sm.OLS(df.loc[df["sport"] == sport, "auc_naive"], df.loc[df["sport"] == sport, ["season", "const"]]).fit()
   arrow = "\\mathit{-}" if auc_regr.pvalues['season'] > 0.05 else "\\uparrow" if auc_regr.params['season'] > 0 else "\\downarrow"
   stars = "***" if auc_regr.pvalues['season'] < 0.001 else "**" if auc_regr.pvalues['season'] < 0.01 else "*" if auc_regr.pvalues['season'] < 0.05 else " "
   print(f"{sport.capitalize()} & ${arrow}$ & ${stars}$ & ${auc_regr.rsquared_adj:.2f}$\\\\")

print()
print("Home Advantage")
print("========================= PageRank =========================")
for sport in df["sport"].drop_duplicates().sort_values():
   home_regr = sm.OLS(df.loc[df["sport"] == sport, "home_adv_pagerank"], df.loc[df["sport"] == sport, ["season", "const"]]).fit()
   arrow = "\\mathit{-}" if home_regr.pvalues['season'] > 0.05 else "\\uparrow" if home_regr.params['season'] > 0 else "\\downarrow"
   stars = "***" if home_regr.pvalues['season'] < 0.001 else "**" if home_regr.pvalues['season'] < 0.01 else "*" if home_regr.pvalues['season'] < 0.05 else " "
   print(f"{sport.capitalize()} & ${arrow}$ & ${stars}$ & ${home_regr.rsquared_adj:.2f}$\\\\")

print("========================= ELO =========================")
for sport in df["sport"].drop_duplicates().sort_values():
   home_regr = sm.OLS(df.loc[df["sport"] == sport, "home_adv_elo"], df.loc[df["sport"] == sport, ["season", "const"]]).fit()
   arrow = "\\mathit{-}" if home_regr.pvalues['season'] > 0.05 else "\\uparrow" if home_regr.params['season'] > 0 else "\\downarrow"
   stars = "***" if home_regr.pvalues['season'] < 0.001 else "**" if home_regr.pvalues['season'] < 0.01 else "*" if home_regr.pvalues['season'] < 0.05 else " "
   print(f"{sport.capitalize()} & ${arrow}$ & ${stars}$ & ${home_regr.rsquared_adj:.2f}$\\\\")

print("========================= Naive =========================")
for sport in df["sport"].drop_duplicates().sort_values():
   home_regr = sm.OLS(df.loc[df["sport"] == sport, "home_adv_naive"], df.loc[df["sport"] == sport, ["season", "const"]]).fit()
   arrow = "\\mathit{-}" if home_regr.pvalues['season'] > 0.05 else "\\uparrow" if home_regr.params['season'] > 0 else "\\downarrow"
   stars = "***" if home_regr.pvalues['season'] < 0.001 else "**" if home_regr.pvalues['season'] < 0.01 else "*" if home_regr.pvalues['season'] < 0.05 else " "
   print(f"{sport.capitalize()} & ${arrow}$ & ${stars}$ & ${home_regr.rsquared_adj:.2f}$\\\\")
