import pandas as pd
import statsmodels.api as sm
from scipy.stats import mannwhitneyu

df = pd.read_csv("figs_2_3_part2.csv", sep = "\t")
df = sm.add_constant(df)

df["draft"] = 0
df.loc[df["sport"] == "football", "draft"] = 1 # NFL has a draft system
df.loc[(df["sport"] == "basket") & (df["league"] == "NBA"), "draft"] = 1 # NBA has a draft system
df.loc[(df["sport"] == "hockey") & (df["league"] == "USA 1"), "draft"] = 1 # NHL has a draft system
df.loc[df["sport"] == "baseball", "draft"] = 1 # All baseball leagues have draft systems

df.loc[df["draft"] == 1, ["auc_pagerank", "home_adv_pagerank"]].to_csv("fig_4_green.csv", index = False, sep = "\t")
df.loc[df["draft"] == 0, ["auc_pagerank", "home_adv_pagerank"]].to_csv("fig_4_red.csv", index = False, sep = "\t")

df.loc[df["draft"] == 1, ["auc_elo", "home_adv_elo"]].to_csv("fig_s1a_s2a_green.csv", index = False, sep = "\t")
df.loc[df["draft"] == 0, ["auc_elo", "home_adv_elo"]].to_csv("fig_s1a_s2a_red.csv", index = False, sep = "\t")

df.loc[df["draft"] == 1, ["auc_naive", "home_adv_naive"]].to_csv("fig_s1b_s2b_green.csv", index = False, sep = "\t")
df.loc[df["draft"] == 0, ["auc_naive", "home_adv_naive"]].to_csv("fig_s1b_s2b_red.csv", index = False, sep = "\t")

print("PageRank Mann Whitney U test")
print(f'AUC (null hypothesis: soccer > baseball): {mannwhitneyu(df.loc[df["draft"] == 1, "auc_pagerank"], df.loc[df["draft"] == 0, "auc_pagerank"], alternative = "less")}')
print(f'Home (null hypothesis: soccer > baseball): {mannwhitneyu(df.loc[df["draft"] == 1, "home_adv_pagerank"], df.loc[df["draft"] == 0, "home_adv_pagerank"], alternative = "less")}')

print("ELO Mann Whitney U test")
print(f'AUC (null hypothesis: soccer > baseball): {mannwhitneyu(df.loc[df["draft"] == 1, "auc_elo"], df.loc[df["draft"] == 0, "auc_elo"], alternative = "less")}')
print(f'Home (null hypothesis: soccer > baseball): {mannwhitneyu(df.loc[df["draft"] == 1, "home_adv_elo"], df.loc[df["draft"] == 0, "home_adv_elo"], alternative = "less")}')

print("Naive Mann Whitney U test")
print(f'AUC (null hypothesis: soccer > baseball): {mannwhitneyu(df.loc[df["draft"] == 1, "auc_naive"], df.loc[df["draft"] == 0, "auc_naive"], alternative = "less")}')
print(f'Home (null hypothesis: soccer > baseball): {mannwhitneyu(df.loc[df["draft"] == 1, "home_adv_naive"], df.loc[df["draft"] == 0, "home_adv_naive"], alternative = "less")}')
